# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.exchange import injective_megavault_rpc_pb2 as exchange_dot_injective__megavault__rpc__pb2


class InjectiveMegavaultRPCStub(object):
    """InjectiveMegavaultRPC defined a gRPC service for Injective Megavault.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetVault = channel.unary_unary(
                '/injective_megavault_rpc.InjectiveMegavaultRPC/GetVault',
                request_serializer=exchange_dot_injective__megavault__rpc__pb2.GetVaultRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__megavault__rpc__pb2.GetVaultResponse.FromString,
                _registered_method=True)
        self.GetUser = channel.unary_unary(
                '/injective_megavault_rpc.InjectiveMegavaultRPC/GetUser',
                request_serializer=exchange_dot_injective__megavault__rpc__pb2.GetUserRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__megavault__rpc__pb2.GetUserResponse.FromString,
                _registered_method=True)
        self.ListSubscriptions = channel.unary_unary(
                '/injective_megavault_rpc.InjectiveMegavaultRPC/ListSubscriptions',
                request_serializer=exchange_dot_injective__megavault__rpc__pb2.ListSubscriptionsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__megavault__rpc__pb2.ListSubscriptionsResponse.FromString,
                _registered_method=True)
        self.ListRedemptions = channel.unary_unary(
                '/injective_megavault_rpc.InjectiveMegavaultRPC/ListRedemptions',
                request_serializer=exchange_dot_injective__megavault__rpc__pb2.ListRedemptionsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__megavault__rpc__pb2.ListRedemptionsResponse.FromString,
                _registered_method=True)
        self.GetOperatorRedemptionBuckets = channel.unary_unary(
                '/injective_megavault_rpc.InjectiveMegavaultRPC/GetOperatorRedemptionBuckets',
                request_serializer=exchange_dot_injective__megavault__rpc__pb2.GetOperatorRedemptionBucketsRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__megavault__rpc__pb2.GetOperatorRedemptionBucketsResponse.FromString,
                _registered_method=True)
        self.TvlHistory = channel.unary_unary(
                '/injective_megavault_rpc.InjectiveMegavaultRPC/TvlHistory',
                request_serializer=exchange_dot_injective__megavault__rpc__pb2.TvlHistoryRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__megavault__rpc__pb2.TvlHistoryResponse.FromString,
                _registered_method=True)
        self.PnlHistory = channel.unary_unary(
                '/injective_megavault_rpc.InjectiveMegavaultRPC/PnlHistory',
                request_serializer=exchange_dot_injective__megavault__rpc__pb2.PnlHistoryRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__megavault__rpc__pb2.PnlHistoryResponse.FromString,
                _registered_method=True)


class InjectiveMegavaultRPCServicer(object):
    """InjectiveMegavaultRPC defined a gRPC service for Injective Megavault.
    """

    def GetVault(self, request, context):
        """Get the vault information
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetUser(self, request, context):
        """Get the user information for a vault
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSubscriptions(self, request, context):
        """List the subscriptions for a vault
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListRedemptions(self, request, context):
        """List the redemptions for a vault
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetOperatorRedemptionBuckets(self, request, context):
        """Get the redemptions buckets for an operator
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TvlHistory(self, request, context):
        """Provide historical TVL data.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PnlHistory(self, request, context):
        """Provide historical PnL data.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InjectiveMegavaultRPCServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetVault': grpc.unary_unary_rpc_method_handler(
                    servicer.GetVault,
                    request_deserializer=exchange_dot_injective__megavault__rpc__pb2.GetVaultRequest.FromString,
                    response_serializer=exchange_dot_injective__megavault__rpc__pb2.GetVaultResponse.SerializeToString,
            ),
            'GetUser': grpc.unary_unary_rpc_method_handler(
                    servicer.GetUser,
                    request_deserializer=exchange_dot_injective__megavault__rpc__pb2.GetUserRequest.FromString,
                    response_serializer=exchange_dot_injective__megavault__rpc__pb2.GetUserResponse.SerializeToString,
            ),
            'ListSubscriptions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSubscriptions,
                    request_deserializer=exchange_dot_injective__megavault__rpc__pb2.ListSubscriptionsRequest.FromString,
                    response_serializer=exchange_dot_injective__megavault__rpc__pb2.ListSubscriptionsResponse.SerializeToString,
            ),
            'ListRedemptions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListRedemptions,
                    request_deserializer=exchange_dot_injective__megavault__rpc__pb2.ListRedemptionsRequest.FromString,
                    response_serializer=exchange_dot_injective__megavault__rpc__pb2.ListRedemptionsResponse.SerializeToString,
            ),
            'GetOperatorRedemptionBuckets': grpc.unary_unary_rpc_method_handler(
                    servicer.GetOperatorRedemptionBuckets,
                    request_deserializer=exchange_dot_injective__megavault__rpc__pb2.GetOperatorRedemptionBucketsRequest.FromString,
                    response_serializer=exchange_dot_injective__megavault__rpc__pb2.GetOperatorRedemptionBucketsResponse.SerializeToString,
            ),
            'TvlHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.TvlHistory,
                    request_deserializer=exchange_dot_injective__megavault__rpc__pb2.TvlHistoryRequest.FromString,
                    response_serializer=exchange_dot_injective__megavault__rpc__pb2.TvlHistoryResponse.SerializeToString,
            ),
            'PnlHistory': grpc.unary_unary_rpc_method_handler(
                    servicer.PnlHistory,
                    request_deserializer=exchange_dot_injective__megavault__rpc__pb2.PnlHistoryRequest.FromString,
                    response_serializer=exchange_dot_injective__megavault__rpc__pb2.PnlHistoryResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective_megavault_rpc.InjectiveMegavaultRPC', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('injective_megavault_rpc.InjectiveMegavaultRPC', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class InjectiveMegavaultRPC(object):
    """InjectiveMegavaultRPC defined a gRPC service for Injective Megavault.
    """

    @staticmethod
    def GetVault(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_megavault_rpc.InjectiveMegavaultRPC/GetVault',
            exchange_dot_injective__megavault__rpc__pb2.GetVaultRequest.SerializeToString,
            exchange_dot_injective__megavault__rpc__pb2.GetVaultResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetUser(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_megavault_rpc.InjectiveMegavaultRPC/GetUser',
            exchange_dot_injective__megavault__rpc__pb2.GetUserRequest.SerializeToString,
            exchange_dot_injective__megavault__rpc__pb2.GetUserResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListSubscriptions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_megavault_rpc.InjectiveMegavaultRPC/ListSubscriptions',
            exchange_dot_injective__megavault__rpc__pb2.ListSubscriptionsRequest.SerializeToString,
            exchange_dot_injective__megavault__rpc__pb2.ListSubscriptionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListRedemptions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_megavault_rpc.InjectiveMegavaultRPC/ListRedemptions',
            exchange_dot_injective__megavault__rpc__pb2.ListRedemptionsRequest.SerializeToString,
            exchange_dot_injective__megavault__rpc__pb2.ListRedemptionsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetOperatorRedemptionBuckets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_megavault_rpc.InjectiveMegavaultRPC/GetOperatorRedemptionBuckets',
            exchange_dot_injective__megavault__rpc__pb2.GetOperatorRedemptionBucketsRequest.SerializeToString,
            exchange_dot_injective__megavault__rpc__pb2.GetOperatorRedemptionBucketsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TvlHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_megavault_rpc.InjectiveMegavaultRPC/TvlHistory',
            exchange_dot_injective__megavault__rpc__pb2.TvlHistoryRequest.SerializeToString,
            exchange_dot_injective__megavault__rpc__pb2.TvlHistoryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def PnlHistory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective_megavault_rpc.InjectiveMegavaultRPC/PnlHistory',
            exchange_dot_injective__megavault__rpc__pb2.PnlHistoryRequest.SerializeToString,
            exchange_dot_injective__megavault__rpc__pb2.PnlHistoryResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/interchain_security/v1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1hyperlane/core/interchain_security/v1/query.proto\x12%hyperlane.core.interchain_security.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x11\x61mino/amino.proto\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\"Z\n\x10QueryIsmsRequest\x12\x46\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xdd\x01\n\x11QueryIsmsResponse\x12\x7f\n\x04isms\x18\x01 \x03(\x0b\x32\x14.google.protobuf.AnyBU\xca\xb4-Qhyperlane.core.v1.01_interchain_security_module.HyperlaneInterchainSecurityModuleR\x04isms\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"!\n\x0fQueryIsmRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"E\n\x10QueryIsmResponse\x12\x31\n\x03ism\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyB\t\xc8\xde\x1f\x00\xa8\xe7\xb0*\x01R\x03ism\"s\n%QueryAnnouncedStorageLocationsRequest\x12\x1d\n\nmailbox_id\x18\x01 \x01(\tR\tmailboxId\x12+\n\x11validator_address\x18\x02 \x01(\tR\x10validatorAddress\"U\n&QueryAnnouncedStorageLocationsResponse\x12+\n\x11storage_locations\x18\x01 \x03(\tR\x10storageLocations\"x\n*QueryLatestAnnouncedStorageLocationRequest\x12\x1d\n\nmailbox_id\x18\x01 \x01(\tR\tmailboxId\x12+\n\x11validator_address\x18\x02 \x01(\tR\x10validatorAddress\"X\n+QueryLatestAnnouncedStorageLocationResponse\x12)\n\x10storage_location\x18\x01 \x01(\tR\x0fstorageLocation2\x81\x07\n\x05Query\x12\x95\x01\n\x04Isms\x12\x37.hyperlane.core.interchain_security.v1.QueryIsmsRequest\x1a\x38.hyperlane.core.interchain_security.v1.QueryIsmsResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/hyperlane/v1/isms\x12\x97\x01\n\x03Ism\x12\x36.hyperlane.core.interchain_security.v1.QueryIsmRequest\x1a\x37.hyperlane.core.interchain_security.v1.QueryIsmResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/hyperlane/v1/isms/{id}\x12\x96\x02\n\x19\x41nnouncedStorageLocations\x12L.hyperlane.core.interchain_security.v1.QueryAnnouncedStorageLocationsRequest\x1aM.hyperlane.core.interchain_security.v1.QueryAnnouncedStorageLocationsResponse\"\\\x82\xd3\xe4\x93\x02V\x12T/hyperlane/v1/mailboxes/{mailbox_id}/announced_storage_locations/{validator_address}\x12\xac\x02\n\x1eLatestAnnouncedStorageLocation\x12Q.hyperlane.core.interchain_security.v1.QueryLatestAnnouncedStorageLocationRequest\x1aR.hyperlane.core.interchain_security.v1.QueryLatestAnnouncedStorageLocationResponse\"c\x82\xd3\xe4\x93\x02]\x12[/hyperlane/v1/mailboxes/{mailbox_id}/announced_storage_locations/{validator_address}/latestB\xbb\x02\n)com.hyperlane.core.interchain_security.v1B\nQueryProtoP\x01ZOgithub.com/bcp-innovations/hyperlane-cosmos/x/core/01_interchain_security/types\xa2\x02\x03HCI\xaa\x02$Hyperlane.Core.InterchainSecurity.V1\xca\x02$Hyperlane\\Core\\InterchainSecurity\\V1\xe2\x02\x30Hyperlane\\Core\\InterchainSecurity\\V1\\GPBMetadata\xea\x02\'Hyperlane::Core::InterchainSecurity::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.interchain_security.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)com.hyperlane.core.interchain_security.v1B\nQueryProtoP\001ZOgithub.com/bcp-innovations/hyperlane-cosmos/x/core/01_interchain_security/types\242\002\003HCI\252\002$Hyperlane.Core.InterchainSecurity.V1\312\002$Hyperlane\\Core\\InterchainSecurity\\V1\342\0020Hyperlane\\Core\\InterchainSecurity\\V1\\GPBMetadata\352\002\'Hyperlane::Core::InterchainSecurity::V1'
  _globals['_QUERYISMSRESPONSE'].fields_by_name['isms']._loaded_options = None
  _globals['_QUERYISMSRESPONSE'].fields_by_name['isms']._serialized_options = b'\312\264-Qhyperlane.core.v1.01_interchain_security_module.HyperlaneInterchainSecurityModule'
  _globals['_QUERYISMRESPONSE'].fields_by_name['ism']._loaded_options = None
  _globals['_QUERYISMRESPONSE'].fields_by_name['ism']._serialized_options = b'\310\336\037\000\250\347\260*\001'
  _globals['_QUERY'].methods_by_name['Isms']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Isms']._serialized_options = b'\202\323\344\223\002\024\022\022/hyperlane/v1/isms'
  _globals['_QUERY'].methods_by_name['Ism']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Ism']._serialized_options = b'\202\323\344\223\002\031\022\027/hyperlane/v1/isms/{id}'
  _globals['_QUERY'].methods_by_name['AnnouncedStorageLocations']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AnnouncedStorageLocations']._serialized_options = b'\202\323\344\223\002V\022T/hyperlane/v1/mailboxes/{mailbox_id}/announced_storage_locations/{validator_address}'
  _globals['_QUERY'].methods_by_name['LatestAnnouncedStorageLocation']._loaded_options = None
  _globals['_QUERY'].methods_by_name['LatestAnnouncedStorageLocation']._serialized_options = b'\202\323\344\223\002]\022[/hyperlane/v1/mailboxes/{mailbox_id}/announced_storage_locations/{validator_address}/latest'
  _globals['_QUERYISMSREQUEST']._serialized_start=261
  _globals['_QUERYISMSREQUEST']._serialized_end=351
  _globals['_QUERYISMSRESPONSE']._serialized_start=354
  _globals['_QUERYISMSRESPONSE']._serialized_end=575
  _globals['_QUERYISMREQUEST']._serialized_start=577
  _globals['_QUERYISMREQUEST']._serialized_end=610
  _globals['_QUERYISMRESPONSE']._serialized_start=612
  _globals['_QUERYISMRESPONSE']._serialized_end=681
  _globals['_QUERYANNOUNCEDSTORAGELOCATIONSREQUEST']._serialized_start=683
  _globals['_QUERYANNOUNCEDSTORAGELOCATIONSREQUEST']._serialized_end=798
  _globals['_QUERYANNOUNCEDSTORAGELOCATIONSRESPONSE']._serialized_start=800
  _globals['_QUERYANNOUNCEDSTORAGELOCATIONSRESPONSE']._serialized_end=885
  _globals['_QUERYLATESTANNOUNCEDSTORAGELOCATIONREQUEST']._serialized_start=887
  _globals['_QUERYLATESTANNOUNCEDSTORAGELOCATIONREQUEST']._serialized_end=1007
  _globals['_QUERYLATESTANNOUNCEDSTORAGELOCATIONRESPONSE']._serialized_start=1009
  _globals['_QUERYLATESTANNOUNCEDSTORAGELOCATIONRESPONSE']._serialized_end=1097
  _globals['_QUERY']._serialized_start=1100
  _globals['_QUERY']._serialized_end=1997
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/interchain_security/v1/events.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2hyperlane/core/interchain_security/v1/events.proto\x12%hyperlane.core.interchain_security.v1\x1a\x14gogoproto/gogo.proto\x1a\x19\x63osmos_proto/cosmos.proto\"\xa0\x01\n\x12\x45ventCreateNoopIsm\x12Z\n\x06ism_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\"\xec\x01\n EventCreateMerkleRootMultisigIsm\x12Z\n\x06ism_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12\x1e\n\nvalidators\x18\x03 \x03(\tR\nvalidators\x12\x1c\n\tthreshold\x18\x04 \x01(\rR\tthreshold\"\xeb\x01\n\x1f\x45ventCreateMessageIdMultisigIsm\x12Z\n\x06ism_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12\x1e\n\nvalidators\x18\x03 \x03(\tR\nvalidators\x12\x1c\n\tthreshold\x18\x04 \x01(\rR\tthreshold\"\xfd\x01\n\x1c\x45ventAnnounceStorageLocation\x12\x62\n\nmailbox_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\tmailboxId\x12\x30\n\x06sender\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x06sender\x12\x1c\n\tvalidator\x18\x03 \x01(\tR\tvalidator\x12)\n\x10storage_location\x18\x04 \x01(\tR\x0fstorageLocation\"\xb0\x02\n\x18\x45ventSetRoutingIsmDomain\x12Z\n\x06ism_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12\x65\n\x0croute_ism_id\x18\x03 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\nrouteIsmId\x12!\n\x0croute_domain\x18\x04 \x01(\rR\x0brouteDomain\"\xcc\x01\n\x1b\x45ventRemoveRoutingIsmDomain\x12Z\n\x06ism_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12!\n\x0croute_domain\x18\x03 \x01(\rR\x0brouteDomain\"\xec\x01\n\x12\x45ventSetRoutingIsm\x12Z\n\x06ism_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12\x1b\n\tnew_owner\x18\x03 \x01(\tR\x08newOwner\x12-\n\x12renounce_ownership\x18\x04 \x01(\x08R\x11renounceOwnership\"\xa3\x01\n\x15\x45ventCreateRoutingIsm\x12Z\n\x06ism_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05ownerB\xbc\x02\n)com.hyperlane.core.interchain_security.v1B\x0b\x45ventsProtoP\x01ZOgithub.com/bcp-innovations/hyperlane-cosmos/x/core/01_interchain_security/types\xa2\x02\x03HCI\xaa\x02$Hyperlane.Core.InterchainSecurity.V1\xca\x02$Hyperlane\\Core\\InterchainSecurity\\V1\xe2\x02\x30Hyperlane\\Core\\InterchainSecurity\\V1\\GPBMetadata\xea\x02\'Hyperlane::Core::InterchainSecurity::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.interchain_security.v1.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)com.hyperlane.core.interchain_security.v1B\013EventsProtoP\001ZOgithub.com/bcp-innovations/hyperlane-cosmos/x/core/01_interchain_security/types\242\002\003HCI\252\002$Hyperlane.Core.InterchainSecurity.V1\312\002$Hyperlane\\Core\\InterchainSecurity\\V1\342\0020Hyperlane\\Core\\InterchainSecurity\\V1\\GPBMetadata\352\002\'Hyperlane::Core::InterchainSecurity::V1'
  _globals['_EVENTCREATENOOPISM'].fields_by_name['ism_id']._loaded_options = None
  _globals['_EVENTCREATENOOPISM'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTCREATENOOPISM'].fields_by_name['owner']._loaded_options = None
  _globals['_EVENTCREATENOOPISM'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTCREATEMERKLEROOTMULTISIGISM'].fields_by_name['ism_id']._loaded_options = None
  _globals['_EVENTCREATEMERKLEROOTMULTISIGISM'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTCREATEMERKLEROOTMULTISIGISM'].fields_by_name['owner']._loaded_options = None
  _globals['_EVENTCREATEMERKLEROOTMULTISIGISM'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTCREATEMESSAGEIDMULTISIGISM'].fields_by_name['ism_id']._loaded_options = None
  _globals['_EVENTCREATEMESSAGEIDMULTISIGISM'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTCREATEMESSAGEIDMULTISIGISM'].fields_by_name['owner']._loaded_options = None
  _globals['_EVENTCREATEMESSAGEIDMULTISIGISM'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTANNOUNCESTORAGELOCATION'].fields_by_name['mailbox_id']._loaded_options = None
  _globals['_EVENTANNOUNCESTORAGELOCATION'].fields_by_name['mailbox_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTANNOUNCESTORAGELOCATION'].fields_by_name['sender']._loaded_options = None
  _globals['_EVENTANNOUNCESTORAGELOCATION'].fields_by_name['sender']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTSETROUTINGISMDOMAIN'].fields_by_name['ism_id']._loaded_options = None
  _globals['_EVENTSETROUTINGISMDOMAIN'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTSETROUTINGISMDOMAIN'].fields_by_name['owner']._loaded_options = None
  _globals['_EVENTSETROUTINGISMDOMAIN'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTSETROUTINGISMDOMAIN'].fields_by_name['route_ism_id']._loaded_options = None
  _globals['_EVENTSETROUTINGISMDOMAIN'].fields_by_name['route_ism_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTREMOVEROUTINGISMDOMAIN'].fields_by_name['ism_id']._loaded_options = None
  _globals['_EVENTREMOVEROUTINGISMDOMAIN'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTREMOVEROUTINGISMDOMAIN'].fields_by_name['owner']._loaded_options = None
  _globals['_EVENTREMOVEROUTINGISMDOMAIN'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTSETROUTINGISM'].fields_by_name['ism_id']._loaded_options = None
  _globals['_EVENTSETROUTINGISM'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTSETROUTINGISM'].fields_by_name['owner']._loaded_options = None
  _globals['_EVENTSETROUTINGISM'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTCREATEROUTINGISM'].fields_by_name['ism_id']._loaded_options = None
  _globals['_EVENTCREATEROUTINGISM'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTCREATEROUTINGISM'].fields_by_name['owner']._loaded_options = None
  _globals['_EVENTCREATEROUTINGISM'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_EVENTCREATENOOPISM']._serialized_start=143
  _globals['_EVENTCREATENOOPISM']._serialized_end=303
  _globals['_EVENTCREATEMERKLEROOTMULTISIGISM']._serialized_start=306
  _globals['_EVENTCREATEMERKLEROOTMULTISIGISM']._serialized_end=542
  _globals['_EVENTCREATEMESSAGEIDMULTISIGISM']._serialized_start=545
  _globals['_EVENTCREATEMESSAGEIDMULTISIGISM']._serialized_end=780
  _globals['_EVENTANNOUNCESTORAGELOCATION']._serialized_start=783
  _globals['_EVENTANNOUNCESTORAGELOCATION']._serialized_end=1036
  _globals['_EVENTSETROUTINGISMDOMAIN']._serialized_start=1039
  _globals['_EVENTSETROUTINGISMDOMAIN']._serialized_end=1343
  _globals['_EVENTREMOVEROUTINGISMDOMAIN']._serialized_start=1346
  _globals['_EVENTREMOVEROUTINGISMDOMAIN']._serialized_end=1550
  _globals['_EVENTSETROUTINGISM']._serialized_start=1553
  _globals['_EVENTSETROUTINGISM']._serialized_end=1789
  _globals['_EVENTCREATEROUTINGISM']._serialized_start=1792
  _globals['_EVENTCREATEROUTINGISM']._serialized_end=1955
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from hyperlane.core.interchain_security.v1 import query_pb2 as hyperlane_dot_core_dot_interchain__security_dot_v1_dot_query__pb2


class QueryStub(object):
    """Query defines the module Query service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Isms = channel.unary_unary(
                '/hyperlane.core.interchain_security.v1.Query/Isms',
                request_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_query__pb2.QueryIsmsRequest.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_query__pb2.QueryIsmsResponse.FromString,
                _registered_method=True)
        self.Ism = channel.unary_unary(
                '/hyperlane.core.interchain_security.v1.Query/Ism',
                request_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_query__pb2.QueryIsmRequest.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_query__pb2.QueryIsmResponse.FromString,
                _registered_method=True)
        self.AnnouncedStorageLocations = channel.unary_unary(
                '/hyperlane.core.interchain_security.v1.Query/AnnouncedStorageLocations',
                request_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_query__pb2.QueryAnnouncedStorageLocationsRequest.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_query__pb2.QueryAnnouncedStorageLocationsResponse.FromString,
                _registered_method=True)
        self.LatestAnnouncedStorageLocation = channel.unary_unary(
                '/hyperlane.core.interchain_security.v1.Query/LatestAnnouncedStorageLocation',
                request_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_query__pb2.QueryLatestAnnouncedStorageLocationRequest.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_query__pb2.QueryLatestAnnouncedStorageLocationResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query defines the module Query service.
    """

    def Isms(self, request, context):
        """Isms ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Ism(self, request, context):
        """Ism ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AnnouncedStorageLocations(self, request, context):
        """AnnouncedStorageLocations ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LatestAnnouncedStorageLocation(self, request, context):
        """LatestAnnouncedStorageLocation ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Isms': grpc.unary_unary_rpc_method_handler(
                    servicer.Isms,
                    request_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_query__pb2.QueryIsmsRequest.FromString,
                    response_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_query__pb2.QueryIsmsResponse.SerializeToString,
            ),
            'Ism': grpc.unary_unary_rpc_method_handler(
                    servicer.Ism,
                    request_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_query__pb2.QueryIsmRequest.FromString,
                    response_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_query__pb2.QueryIsmResponse.SerializeToString,
            ),
            'AnnouncedStorageLocations': grpc.unary_unary_rpc_method_handler(
                    servicer.AnnouncedStorageLocations,
                    request_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_query__pb2.QueryAnnouncedStorageLocationsRequest.FromString,
                    response_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_query__pb2.QueryAnnouncedStorageLocationsResponse.SerializeToString,
            ),
            'LatestAnnouncedStorageLocation': grpc.unary_unary_rpc_method_handler(
                    servicer.LatestAnnouncedStorageLocation,
                    request_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_query__pb2.QueryLatestAnnouncedStorageLocationRequest.FromString,
                    response_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_query__pb2.QueryLatestAnnouncedStorageLocationResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'hyperlane.core.interchain_security.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('hyperlane.core.interchain_security.v1.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the module Query service.
    """

    @staticmethod
    def Isms(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.interchain_security.v1.Query/Isms',
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_query__pb2.QueryIsmsRequest.SerializeToString,
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_query__pb2.QueryIsmsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Ism(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.interchain_security.v1.Query/Ism',
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_query__pb2.QueryIsmRequest.SerializeToString,
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_query__pb2.QueryIsmResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AnnouncedStorageLocations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.interchain_security.v1.Query/AnnouncedStorageLocations',
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_query__pb2.QueryAnnouncedStorageLocationsRequest.SerializeToString,
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_query__pb2.QueryAnnouncedStorageLocationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def LatestAnnouncedStorageLocation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.interchain_security.v1.Query/LatestAnnouncedStorageLocation',
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_query__pb2.QueryLatestAnnouncedStorageLocationRequest.SerializeToString,
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_query__pb2.QueryLatestAnnouncedStorageLocationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from hyperlane.core.interchain_security.v1 import tx_pb2 as hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the module Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateMessageIdMultisigIsm = channel.unary_unary(
                '/hyperlane.core.interchain_security.v1.Msg/CreateMessageIdMultisigIsm',
                request_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateMessageIdMultisigIsm.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateMessageIdMultisigIsmResponse.FromString,
                _registered_method=True)
        self.CreateMerkleRootMultisigIsm = channel.unary_unary(
                '/hyperlane.core.interchain_security.v1.Msg/CreateMerkleRootMultisigIsm',
                request_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateMerkleRootMultisigIsm.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateMerkleRootMultisigIsmResponse.FromString,
                _registered_method=True)
        self.CreateNoopIsm = channel.unary_unary(
                '/hyperlane.core.interchain_security.v1.Msg/CreateNoopIsm',
                request_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateNoopIsm.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateNoopIsmResponse.FromString,
                _registered_method=True)
        self.CreateRoutingIsm = channel.unary_unary(
                '/hyperlane.core.interchain_security.v1.Msg/CreateRoutingIsm',
                request_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateRoutingIsm.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateRoutingIsmResponse.FromString,
                _registered_method=True)
        self.SetRoutingIsmDomain = channel.unary_unary(
                '/hyperlane.core.interchain_security.v1.Msg/SetRoutingIsmDomain',
                request_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgSetRoutingIsmDomain.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgSetRoutingIsmDomainResponse.FromString,
                _registered_method=True)
        self.RemoveRoutingIsmDomain = channel.unary_unary(
                '/hyperlane.core.interchain_security.v1.Msg/RemoveRoutingIsmDomain',
                request_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgRemoveRoutingIsmDomain.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgRemoveRoutingIsmDomainResponse.FromString,
                _registered_method=True)
        self.UpdateRoutingIsmOwner = channel.unary_unary(
                '/hyperlane.core.interchain_security.v1.Msg/UpdateRoutingIsmOwner',
                request_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgUpdateRoutingIsmOwner.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgUpdateRoutingIsmOwnerResponse.FromString,
                _registered_method=True)
        self.AnnounceValidator = channel.unary_unary(
                '/hyperlane.core.interchain_security.v1.Msg/AnnounceValidator',
                request_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgAnnounceValidator.SerializeToString,
                response_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgAnnounceValidatorResponse.FromString,
                _registered_method=True)


class MsgServicer(object):
    """Msg defines the module Msg service.
    """

    def CreateMessageIdMultisigIsm(self, request, context):
        """CreateMessageIdMultisigIsm ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateMerkleRootMultisigIsm(self, request, context):
        """CreateMerkleRootMultisigIsm ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateNoopIsm(self, request, context):
        """CreateNoopIsm ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateRoutingIsm(self, request, context):
        """CreateRoutingIsm ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetRoutingIsmDomain(self, request, context):
        """SetRoutingIsmDomain ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveRoutingIsmDomain(self, request, context):
        """RemoveRoutingIsmDomain ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateRoutingIsmOwner(self, request, context):
        """UpdateRoutingIsmOwner ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AnnounceValidator(self, request, context):
        """AnnounceValidator ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateMessageIdMultisigIsm': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateMessageIdMultisigIsm,
                    request_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateMessageIdMultisigIsm.FromString,
                    response_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateMessageIdMultisigIsmResponse.SerializeToString,
            ),
            'CreateMerkleRootMultisigIsm': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateMerkleRootMultisigIsm,
                    request_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateMerkleRootMultisigIsm.FromString,
                    response_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateMerkleRootMultisigIsmResponse.SerializeToString,
            ),
            'CreateNoopIsm': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNoopIsm,
                    request_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateNoopIsm.FromString,
                    response_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateNoopIsmResponse.SerializeToString,
            ),
            'CreateRoutingIsm': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateRoutingIsm,
                    request_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateRoutingIsm.FromString,
                    response_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateRoutingIsmResponse.SerializeToString,
            ),
            'SetRoutingIsmDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.SetRoutingIsmDomain,
                    request_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgSetRoutingIsmDomain.FromString,
                    response_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgSetRoutingIsmDomainResponse.SerializeToString,
            ),
            'RemoveRoutingIsmDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveRoutingIsmDomain,
                    request_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgRemoveRoutingIsmDomain.FromString,
                    response_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgRemoveRoutingIsmDomainResponse.SerializeToString,
            ),
            'UpdateRoutingIsmOwner': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateRoutingIsmOwner,
                    request_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgUpdateRoutingIsmOwner.FromString,
                    response_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgUpdateRoutingIsmOwnerResponse.SerializeToString,
            ),
            'AnnounceValidator': grpc.unary_unary_rpc_method_handler(
                    servicer.AnnounceValidator,
                    request_deserializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgAnnounceValidator.FromString,
                    response_serializer=hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgAnnounceValidatorResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'hyperlane.core.interchain_security.v1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('hyperlane.core.interchain_security.v1.Msg', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the module Msg service.
    """

    @staticmethod
    def CreateMessageIdMultisigIsm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.interchain_security.v1.Msg/CreateMessageIdMultisigIsm',
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateMessageIdMultisigIsm.SerializeToString,
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateMessageIdMultisigIsmResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateMerkleRootMultisigIsm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.interchain_security.v1.Msg/CreateMerkleRootMultisigIsm',
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateMerkleRootMultisigIsm.SerializeToString,
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateMerkleRootMultisigIsmResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateNoopIsm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.interchain_security.v1.Msg/CreateNoopIsm',
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateNoopIsm.SerializeToString,
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateNoopIsmResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateRoutingIsm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.interchain_security.v1.Msg/CreateRoutingIsm',
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateRoutingIsm.SerializeToString,
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgCreateRoutingIsmResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetRoutingIsmDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.interchain_security.v1.Msg/SetRoutingIsmDomain',
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgSetRoutingIsmDomain.SerializeToString,
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgSetRoutingIsmDomainResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RemoveRoutingIsmDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.interchain_security.v1.Msg/RemoveRoutingIsmDomain',
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgRemoveRoutingIsmDomain.SerializeToString,
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgRemoveRoutingIsmDomainResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateRoutingIsmOwner(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.interchain_security.v1.Msg/UpdateRoutingIsmOwner',
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgUpdateRoutingIsmOwner.SerializeToString,
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgUpdateRoutingIsmOwnerResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AnnounceValidator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.core.interchain_security.v1.Msg/AnnounceValidator',
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgAnnounceValidator.SerializeToString,
            hyperlane_dot_core_dot_interchain__security_dot_v1_dot_tx__pb2.MsgAnnounceValidatorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_megavault_rpc.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&exchange/injective_megavault_rpc.proto\x12\x17injective_megavault_rpc\"6\n\x0fGetVaultRequest\x12#\n\rvault_address\x18\x01 \x01(\tR\x0cvaultAddress\"H\n\x10GetVaultResponse\x12\x34\n\x05vault\x18\x01 \x01(\x0b\x32\x1e.injective_megavault_rpc.VaultR\x05vault\"\xe4\x04\n\x05Vault\x12)\n\x10\x63ontract_address\x18\x01 \x01(\tR\x0f\x63ontractAddress\x12#\n\rcontract_name\x18\x02 \x01(\tR\x0c\x63ontractName\x12)\n\x10\x63ontract_version\x18\x03 \x01(\tR\x0f\x63ontractVersion\x12\x14\n\x05\x61\x64min\x18\x04 \x01(\tR\x05\x61\x64min\x12\x19\n\x08lp_denom\x18\x05 \x01(\tR\x07lpDenom\x12\x1f\n\x0bquote_denom\x18\x06 \x01(\tR\nquoteDenom\x12?\n\toperators\x18\x07 \x03(\x0b\x32!.injective_megavault_rpc.OperatorR\toperators\x12\x43\n\nincentives\x18\x08 \x01(\x0b\x32#.injective_megavault_rpc.IncentivesR\nincentives\x12\x41\n\ntarget_apr\x18\t \x01(\x0b\x32\".injective_megavault_rpc.TargetAprR\ttargetApr\x12\x39\n\x05stats\x18\n \x01(\x0b\x32#.injective_megavault_rpc.VaultStatsR\x05stats\x12%\n\x0e\x63reated_height\x18\x0b \x01(\x12R\rcreatedHeight\x12\x1d\n\ncreated_at\x18\x0c \x01(\x12R\tcreatedAt\x12%\n\x0eupdated_height\x18\r \x01(\x12R\rupdatedHeight\x12\x1d\n\nupdated_at\x18\x0e \x01(\x12R\tupdatedAt\"\x82\x02\n\x08Operator\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12!\n\x0ctotal_amount\x18\x02 \x01(\tR\x0btotalAmount\x12.\n\x13total_liquid_amount\x18\x03 \x01(\tR\x11totalLiquidAmount\x12%\n\x0eupdated_height\x18\x04 \x01(\x12R\rupdatedHeight\x12\x1d\n\nupdated_at\x18\x05 \x01(\x12R\tupdatedAt\x12\x1e\n\npercentage\x18\x06 \x01(\tR\npercentage\x12#\n\rsubaccount_id\x18\x07 \x01(\tR\x0csubaccountId\"\x84\x01\n\nIncentives\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x16\n\x06\x61mount\x18\x02 \x01(\tR\x06\x61mount\x12%\n\x0eupdated_height\x18\x03 \x01(\x12R\rupdatedHeight\x12\x1d\n\nupdated_at\x18\x04 \x01(\x12R\tupdatedAt\"\xb5\x01\n\tTargetApr\x12\x10\n\x03\x61pr\x18\x01 \x01(\tR\x03\x61pr\x12\'\n\x0fupper_threshold\x18\x02 \x01(\tR\x0eupperThreshold\x12\'\n\x0flower_threshold\x18\x03 \x01(\tR\x0elowerThreshold\x12%\n\x0eupdated_height\x18\x04 \x01(\x12R\rupdatedHeight\x12\x1d\n\nupdated_at\x18\x05 \x01(\x12R\tupdatedAt\"\xbd\x04\n\nVaultStats\x12\x36\n\x17total_subscribed_amount\x18\x01 \x01(\tR\x15totalSubscribedAmount\x12\x32\n\x15total_redeemed_amount\x18\x02 \x01(\tR\x13totalRedeemedAmount\x12%\n\x0e\x63urrent_amount\x18\x03 \x01(\tR\rcurrentAmount\x12I\n!current_amount_without_incentives\x18\x04 \x01(\tR\x1e\x63urrentAmountWithoutIncentives\x12*\n\x11\x63urrent_lp_amount\x18\x05 \x01(\tR\x0f\x63urrentLpAmount\x12(\n\x10\x63urrent_lp_price\x18\x06 \x01(\tR\x0e\x63urrentLpPrice\x12\x33\n\x03pnl\x18\x07 \x01(\x0b\x32!.injective_megavault_rpc.PnlStatsR\x03pnl\x12H\n\nvolatility\x18\x08 \x01(\x0b\x32(.injective_megavault_rpc.VolatilityStatsR\nvolatility\x12\x33\n\x03\x61pr\x18\t \x01(\x0b\x32!.injective_megavault_rpc.AprStatsR\x03\x61pr\x12G\n\x0cmax_drawdown\x18\n \x01(\x0b\x32$.injective_megavault_rpc.MaxDrawdownR\x0bmaxDrawdown\"\x8b\x01\n\x08PnlStats\x12\x46\n\nunrealized\x18\x01 \x01(\x0b\x32&.injective_megavault_rpc.UnrealizedPnlR\nunrealized\x12\x37\n\x08\x61ll_time\x18\x02 \x01(\x0b\x32\x1c.injective_megavault_rpc.PnlR\x07\x61llTime\"E\n\rUnrealizedPnl\x12\x14\n\x05value\x18\x01 \x01(\tR\x05value\x12\x1e\n\npercentage\x18\x02 \x01(\tR\npercentage\"\xce\x01\n\x03Pnl\x12\x14\n\x05value\x18\x01 \x01(\tR\x05value\x12\x1e\n\npercentage\x18\x02 \x01(\tR\npercentage\x12\x36\n\x17total_amount_subscribed\x18\x03 \x01(\tR\x15totalAmountSubscribed\x12\x32\n\x15total_amount_redeemed\x18\x04 \x01(\tR\x13totalAmountRedeemed\x12%\n\x0e\x63urrent_amount\x18\x05 \x01(\tR\rcurrentAmount\"W\n\x0fVolatilityStats\x12\x44\n\x0bthirty_days\x18\x01 \x01(\x0b\x32#.injective_megavault_rpc.VolatilityR\nthirtyDays\"\"\n\nVolatility\x12\x14\n\x05value\x18\x01 \x01(\tR\x05value\"I\n\x08\x41prStats\x12=\n\x0bthirty_days\x18\x01 \x01(\x0b\x32\x1c.injective_megavault_rpc.AprR\nthirtyDays\"q\n\x03\x41pr\x12\x14\n\x05value\x18\x01 \x01(\tR\x05value\x12*\n\x11original_lp_price\x18\x02 \x01(\tR\x0foriginalLpPrice\x12(\n\x10\x63urrent_lp_price\x18\x03 \x01(\tR\x0e\x63urrentLpPrice\"L\n\x0bMaxDrawdown\x12\x14\n\x05value\x18\x01 \x01(\tR\x05value\x12\'\n\x10latest_pn_l_peak\x18\x02 \x01(\tR\rlatestPnLPeak\"X\n\x0eGetUserRequest\x12#\n\rvault_address\x18\x01 \x01(\tR\x0cvaultAddress\x12!\n\x0cuser_address\x18\x02 \x01(\tR\x0buserAddress\"D\n\x0fGetUserResponse\x12\x31\n\x04user\x18\x01 \x01(\x0b\x32\x1d.injective_megavault_rpc.UserR\x04user\"\x91\x02\n\x04User\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12)\n\x10\x63ontract_address\x18\x02 \x01(\tR\x0f\x63ontractAddress\x12\x38\n\x05stats\x18\x03 \x01(\x0b\x32\".injective_megavault_rpc.UserStatsR\x05stats\x12%\n\x0e\x63reated_height\x18\x04 \x01(\x12R\rcreatedHeight\x12\x1d\n\ncreated_at\x18\x05 \x01(\x12R\tcreatedAt\x12%\n\x0eupdated_height\x18\x06 \x01(\x12R\rupdatedHeight\x12\x1d\n\nupdated_at\x18\x07 \x01(\x12R\tupdatedAt\"\xbc\x01\n\tUserStats\x12%\n\x0e\x63urrent_amount\x18\x01 \x01(\tR\rcurrentAmount\x12*\n\x11\x63urrent_lp_amount\x18\x02 \x01(\tR\x0f\x63urrentLpAmount\x12\x33\n\x03pnl\x18\x03 \x01(\x0b\x32!.injective_megavault_rpc.PnlStatsR\x03pnl\x12\'\n\x0f\x64\x65posited_value\x18\x04 \x01(\tR\x0e\x64\x65positedValue\"\xab\x01\n\x18ListSubscriptionsRequest\x12#\n\rvault_address\x18\x01 \x01(\tR\x0cvaultAddress\x12!\n\x0cuser_address\x18\x02 \x01(\tR\x0buserAddress\x12\x16\n\x06status\x18\x03 \x01(\tR\x06status\x12\x19\n\x08per_page\x18\x04 \x01(\x11R\x07perPage\x12\x14\n\x05token\x18\x05 \x01(\tR\x05token\"|\n\x19ListSubscriptionsResponse\x12K\n\rsubscriptions\x18\x01 \x03(\x0b\x32%.injective_megavault_rpc.SubscriptionR\rsubscriptions\x12\x12\n\x04next\x18\x02 \x03(\tR\x04next\"\x84\x03\n\x0cSubscription\x12)\n\x10\x63ontract_address\x18\x01 \x01(\tR\x0f\x63ontractAddress\x12\x12\n\x04user\x18\x02 \x01(\tR\x04user\x12\x14\n\x05index\x18\x03 \x01(\x12R\x05index\x12\x1b\n\tlp_amount\x18\x04 \x01(\tR\x08lpAmount\x12\x16\n\x06\x61mount\x18\x05 \x01(\tR\x06\x61mount\x12\x16\n\x06status\x18\x06 \x01(\tR\x06status\x12%\n\x0e\x63reated_height\x18\x07 \x01(\x12R\rcreatedHeight\x12\x1d\n\ncreated_at\x18\x08 \x01(\x12R\tcreatedAt\x12\'\n\x0f\x65xecuted_height\x18\t \x01(\x12R\x0e\x65xecutedHeight\x12\x1f\n\x0b\x65xecuted_at\x18\n \x01(\x12R\nexecutedAt\x12\x42\n\x03log\x18\x0b \x03(\x0b\x32\x30.injective_megavault_rpc.OperationStatusLogEntryR\x03log\"\x8c\x01\n\x17OperationStatusLogEntry\x12\x16\n\x06status\x18\x01 \x01(\tR\x06status\x12\x17\n\x07tx_hash\x18\x02 \x01(\tR\x06txHash\x12!\n\x0c\x62lock_height\x18\x03 \x01(\x12R\x0b\x62lockHeight\x12\x1d\n\nblock_time\x18\x04 \x01(\x12R\tblockTime\"\xa9\x01\n\x16ListRedemptionsRequest\x12#\n\rvault_address\x18\x01 \x01(\tR\x0cvaultAddress\x12!\n\x0cuser_address\x18\x02 \x01(\tR\x0buserAddress\x12\x16\n\x06status\x18\x03 \x01(\tR\x06status\x12\x19\n\x08per_page\x18\x04 \x01(\x11R\x07perPage\x12\x14\n\x05token\x18\x05 \x01(\tR\x05token\"t\n\x17ListRedemptionsResponse\x12\x45\n\x0bredemptions\x18\x01 \x03(\x0b\x32#.injective_megavault_rpc.RedemptionR\x0bredemptions\x12\x12\n\x04next\x18\x02 \x03(\tR\x04next\"\x99\x03\n\nRedemption\x12)\n\x10\x63ontract_address\x18\x01 \x01(\tR\x0f\x63ontractAddress\x12\x12\n\x04user\x18\x02 \x01(\tR\x04user\x12\x14\n\x05index\x18\x03 \x01(\x12R\x05index\x12\x1b\n\tlp_amount\x18\x04 \x01(\tR\x08lpAmount\x12\x16\n\x06\x61mount\x18\x05 \x01(\tR\x06\x61mount\x12\x16\n\x06status\x18\x06 \x01(\tR\x06status\x12\x15\n\x06\x64ue_at\x18\x07 \x01(\x12R\x05\x64ueAt\x12%\n\x0e\x63reated_height\x18\x08 \x01(\x12R\rcreatedHeight\x12\x1d\n\ncreated_at\x18\t \x01(\x12R\tcreatedAt\x12\'\n\x0f\x65xecuted_height\x18\n \x01(\x12R\x0e\x65xecutedHeight\x12\x1f\n\x0b\x65xecuted_at\x18\x0b \x01(\x12R\nexecutedAt\x12\x42\n\x03log\x18\x0c \x03(\x0b\x32\x30.injective_megavault_rpc.OperationStatusLogEntryR\x03log\"u\n#GetOperatorRedemptionBucketsRequest\x12#\n\rvault_address\x18\x01 \x01(\tR\x0cvaultAddress\x12)\n\x10operator_address\x18\x02 \x01(\tR\x0foperatorAddress\"k\n$GetOperatorRedemptionBucketsResponse\x12\x43\n\x07\x62uckets\x18\x01 \x03(\x0b\x32).injective_megavault_rpc.RedemptionBucketR\x07\x62uckets\"\xab\x01\n\x10RedemptionBucket\x12\x16\n\x06\x62ucket\x18\x01 \x01(\tR\x06\x62ucket\x12-\n\x13lp_amount_to_redeem\x18\x02 \x01(\tR\x10lpAmountToRedeem\x12#\n\rneeded_amount\x18\x03 \x01(\tR\x0cneededAmount\x12+\n\x11missing_liquidity\x18\x04 \x01(\tR\x10missingLiquidity\"v\n\x11TvlHistoryRequest\x12#\n\rvault_address\x18\x01 \x01(\tR\x0cvaultAddress\x12\x14\n\x05since\x18\x02 \x01(\x12R\x05since\x12&\n\x0fmax_data_points\x18\x03 \x01(\x11R\rmaxDataPoints\"V\n\x12TvlHistoryResponse\x12@\n\x07history\x18\x01 \x03(\x0b\x32&.injective_megavault_rpc.HistoricalTVLR\x07history\"+\n\rHistoricalTVL\x12\x0c\n\x01t\x18\x01 \x01(\x12R\x01t\x12\x0c\n\x01v\x18\x02 \x01(\tR\x01v\"v\n\x11PnlHistoryRequest\x12#\n\rvault_address\x18\x01 \x01(\tR\x0cvaultAddress\x12\x14\n\x05since\x18\x02 \x01(\x12R\x05since\x12&\n\x0fmax_data_points\x18\x03 \x01(\x11R\rmaxDataPoints\"V\n\x12PnlHistoryResponse\x12@\n\x07history\x18\x01 \x03(\x0b\x32&.injective_megavault_rpc.HistoricalPnLR\x07history\"+\n\rHistoricalPnL\x12\x0c\n\x01t\x18\x01 \x01(\x12R\x01t\x12\x0c\n\x01v\x18\x02 \x01(\tR\x01v2\xb4\x06\n\x15InjectiveMegavaultRPC\x12_\n\x08GetVault\x12(.injective_megavault_rpc.GetVaultRequest\x1a).injective_megavault_rpc.GetVaultResponse\x12\\\n\x07GetUser\x12\'.injective_megavault_rpc.GetUserRequest\x1a(.injective_megavault_rpc.GetUserResponse\x12z\n\x11ListSubscriptions\x12\x31.injective_megavault_rpc.ListSubscriptionsRequest\x1a\x32.injective_megavault_rpc.ListSubscriptionsResponse\x12t\n\x0fListRedemptions\x12/.injective_megavault_rpc.ListRedemptionsRequest\x1a\x30.injective_megavault_rpc.ListRedemptionsResponse\x12\x9b\x01\n\x1cGetOperatorRedemptionBuckets\x12<.injective_megavault_rpc.GetOperatorRedemptionBucketsRequest\x1a=.injective_megavault_rpc.GetOperatorRedemptionBucketsResponse\x12\x65\n\nTvlHistory\x12*.injective_megavault_rpc.TvlHistoryRequest\x1a+.injective_megavault_rpc.TvlHistoryResponse\x12\x65\n\nPnlHistory\x12*.injective_megavault_rpc.PnlHistoryRequest\x1a+.injective_megavault_rpc.PnlHistoryResponseB\xc9\x01\n\x1b\x63om.injective_megavault_rpcB\x1aInjectiveMegavaultRpcProtoP\x01Z\x1a/injective_megavault_rpcpb\xa2\x02\x03IXX\xaa\x02\x15InjectiveMegavaultRpc\xca\x02\x15InjectiveMegavaultRpc\xe2\x02!InjectiveMegavaultRpc\\GPBMetadata\xea\x02\x15InjectiveMegavaultRpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_megavault_rpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033com.injective_megavault_rpcB\032InjectiveMegavaultRpcProtoP\001Z\032/injective_megavault_rpcpb\242\002\003IXX\252\002\025InjectiveMegavaultRpc\312\002\025InjectiveMegavaultRpc\342\002!InjectiveMegavaultRpc\\GPBMetadata\352\002\025InjectiveMegavaultRpc'
  _globals['_GETVAULTREQUEST']._serialized_start=67
  _globals['_GETVAULTREQUEST']._serialized_end=121
  _globals['_GETVAULTRESPONSE']._serialized_start=123
  _globals['_GETVAULTRESPONSE']._serialized_end=195
  _globals['_VAULT']._serialized_start=198
  _globals['_VAULT']._serialized_end=810
  _globals['_OPERATOR']._serialized_start=813
  _globals['_OPERATOR']._serialized_end=1071
  _globals['_INCENTIVES']._serialized_start=1074
  _globals['_INCENTIVES']._serialized_end=1206
  _globals['_TARGETAPR']._serialized_start=1209
  _globals['_TARGETAPR']._serialized_end=1390
  _globals['_VAULTSTATS']._serialized_start=1393
  _globals['_VAULTSTATS']._serialized_end=1966
  _globals['_PNLSTATS']._serialized_start=1969
  _globals['_PNLSTATS']._serialized_end=2108
  _globals['_UNREALIZEDPNL']._serialized_start=2110
  _globals['_UNREALIZEDPNL']._serialized_end=2179
  _globals['_PNL']._serialized_start=2182
  _globals['_PNL']._serialized_end=2388
  _globals['_VOLATILITYSTATS']._serialized_start=2390
  _globals['_VOLATILITYSTATS']._serialized_end=2477
  _globals['_VOLATILITY']._serialized_start=2479
  _globals['_VOLATILITY']._serialized_end=2513
  _globals['_APRSTATS']._serialized_start=2515
  _globals['_APRSTATS']._serialized_end=2588
  _globals['_APR']._serialized_start=2590
  _globals['_APR']._serialized_end=2703
  _globals['_MAXDRAWDOWN']._serialized_start=2705
  _globals['_MAXDRAWDOWN']._serialized_end=2781
  _globals['_GETUSERREQUEST']._serialized_start=2783
  _globals['_GETUSERREQUEST']._serialized_end=2871
  _globals['_GETUSERRESPONSE']._serialized_start=2873
  _globals['_GETUSERRESPONSE']._serialized_end=2941
  _globals['_USER']._serialized_start=2944
  _globals['_USER']._serialized_end=3217
  _globals['_USERSTATS']._serialized_start=3220
  _globals['_USERSTATS']._serialized_end=3408
  _globals['_LISTSUBSCRIPTIONSREQUEST']._serialized_start=3411
  _globals['_LISTSUBSCRIPTIONSREQUEST']._serialized_end=3582
  _globals['_LISTSUBSCRIPTIONSRESPONSE']._serialized_start=3584
  _globals['_LISTSUBSCRIPTIONSRESPONSE']._serialized_end=3708
  _globals['_SUBSCRIPTION']._serialized_start=3711
  _globals['_SUBSCRIPTION']._serialized_end=4099
  _globals['_OPERATIONSTATUSLOGENTRY']._serialized_start=4102
  _globals['_OPERATIONSTATUSLOGENTRY']._serialized_end=4242
  _globals['_LISTREDEMPTIONSREQUEST']._serialized_start=4245
  _globals['_LISTREDEMPTIONSREQUEST']._serialized_end=4414
  _globals['_LISTREDEMPTIONSRESPONSE']._serialized_start=4416
  _globals['_LISTREDEMPTIONSRESPONSE']._serialized_end=4532
  _globals['_REDEMPTION']._serialized_start=4535
  _globals['_REDEMPTION']._serialized_end=4944
  _globals['_GETOPERATORREDEMPTIONBUCKETSREQUEST']._serialized_start=4946
  _globals['_GETOPERATORREDEMPTIONBUCKETSREQUEST']._serialized_end=5063
  _globals['_GETOPERATORREDEMPTIONBUCKETSRESPONSE']._serialized_start=5065
  _globals['_GETOPERATORREDEMPTIONBUCKETSRESPONSE']._serialized_end=5172
  _globals['_REDEMPTIONBUCKET']._serialized_start=5175
  _globals['_REDEMPTIONBUCKET']._serialized_end=5346
  _globals['_TVLHISTORYREQUEST']._serialized_start=5348
  _globals['_TVLHISTORYREQUEST']._serialized_end=5466
  _globals['_TVLHISTORYRESPONSE']._serialized_start=5468
  _globals['_TVLHISTORYRESPONSE']._serialized_end=5554
  _globals['_HISTORICALTVL']._serialized_start=5556
  _globals['_HISTORICALTVL']._serialized_end=5599
  _globals['_PNLHISTORYREQUEST']._serialized_start=5601
  _globals['_PNLHISTORYREQUEST']._serialized_end=5719
  _globals['_PNLHISTORYRESPONSE']._serialized_start=5721
  _globals['_PNLHISTORYRESPONSE']._serialized_end=5807
  _globals['_HISTORICALPNL']._serialized_start=5809
  _globals['_HISTORICALPNL']._serialized_end=5852
  _globals['_INJECTIVEMEGAVAULTRPC']._serialized_start=5855
  _globals['_INJECTIVEMEGAVAULTRPC']._serialized_end=6675
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/peggy/v1/rate_limit.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#injective/peggy/v1/rate_limit.proto\x12\x12injective.peggy.v1\x1a\x14gogoproto/gogo.proto\"\x85\x03\n\tRateLimit\x12#\n\rtoken_address\x18\x01 \x01(\tR\x0ctokenAddress\x12%\n\x0etoken_decimals\x18\x02 \x01(\rR\rtokenDecimals\x12$\n\x0etoken_price_id\x18\x03 \x01(\tR\x0ctokenPriceId\x12*\n\x11rate_limit_window\x18\x04 \x01(\x04R\x0frateLimitWindow\x12I\n\x0erate_limit_usd\x18\x05 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0crateLimitUsd\x12M\n\x13\x61\x62solute_mint_limit\x18\x06 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x11\x61\x62soluteMintLimit\x12@\n\ttransfers\x18\x07 \x03(\x0b\x32\".injective.peggy.v1.BridgeTransferR\ttransfers\"\x89\x01\n\x0e\x42ridgeTransfer\x12\x35\n\x06\x61mount\x18\x01 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x06\x61mount\x12!\n\x0c\x62lock_number\x18\x02 \x01(\x04R\x0b\x62lockNumber\x12\x1d\n\nis_deposit\x18\x03 \x01(\x08R\tisDepositB\xdf\x01\n\x16\x63om.injective.peggy.v1B\x0eRateLimitProtoP\x01ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types\xa2\x02\x03IPX\xaa\x02\x12Injective.Peggy.V1\xca\x02\x12Injective\\Peggy\\V1\xe2\x02\x1eInjective\\Peggy\\V1\\GPBMetadata\xea\x02\x14Injective::Peggy::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.peggy.v1.rate_limit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.injective.peggy.v1B\016RateLimitProtoP\001ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types\242\002\003IPX\252\002\022Injective.Peggy.V1\312\002\022Injective\\Peggy\\V1\342\002\036Injective\\Peggy\\V1\\GPBMetadata\352\002\024Injective::Peggy::V1'
  _globals['_RATELIMIT'].fields_by_name['rate_limit_usd']._loaded_options = None
  _globals['_RATELIMIT'].fields_by_name['rate_limit_usd']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_RATELIMIT'].fields_by_name['absolute_mint_limit']._loaded_options = None
  _globals['_RATELIMIT'].fields_by_name['absolute_mint_limit']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_BRIDGETRANSFER'].fields_by_name['amount']._loaded_options = None
  _globals['_BRIDGETRANSFER'].fields_by_name['amount']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_RATELIMIT']._serialized_start=82
  _globals['_RATELIMIT']._serialized_end=471
  _globals['_BRIDGETRANSFER']._serialized_start=474
  _globals['_BRIDGETRANSFER']._serialized_end=611
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from hyperlane.warp.v1 import query_pb2 as hyperlane_dot_warp_dot_v1_dot_query__pb2


class QueryStub(object):
    """Query defines the module Query service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Tokens = channel.unary_unary(
                '/hyperlane.warp.v1.Query/Tokens',
                request_serializer=hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryTokensRequest.SerializeToString,
                response_deserializer=hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryTokensResponse.FromString,
                _registered_method=True)
        self.Token = channel.unary_unary(
                '/hyperlane.warp.v1.Query/Token',
                request_serializer=hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryTokenRequest.SerializeToString,
                response_deserializer=hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryTokenResponse.FromString,
                _registered_method=True)
        self.BridgedSupply = channel.unary_unary(
                '/hyperlane.warp.v1.Query/BridgedSupply',
                request_serializer=hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryBridgedSupplyRequest.SerializeToString,
                response_deserializer=hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryBridgedSupplyResponse.FromString,
                _registered_method=True)
        self.RemoteRouters = channel.unary_unary(
                '/hyperlane.warp.v1.Query/RemoteRouters',
                request_serializer=hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryRemoteRoutersRequest.SerializeToString,
                response_deserializer=hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryRemoteRoutersResponse.FromString,
                _registered_method=True)
        self.QuoteRemoteTransfer = channel.unary_unary(
                '/hyperlane.warp.v1.Query/QuoteRemoteTransfer',
                request_serializer=hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryQuoteRemoteTransferRequest.SerializeToString,
                response_deserializer=hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryQuoteRemoteTransferResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query defines the module Query service.
    """

    def Tokens(self, request, context):
        """Tokens ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Token(self, request, context):
        """Token ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BridgedSupply(self, request, context):
        """BridgedSupply ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoteRouters(self, request, context):
        """RemoteRouters ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def QuoteRemoteTransfer(self, request, context):
        """QuoteRemoteTransfer ...
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Tokens': grpc.unary_unary_rpc_method_handler(
                    servicer.Tokens,
                    request_deserializer=hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryTokensRequest.FromString,
                    response_serializer=hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryTokensResponse.SerializeToString,
            ),
            'Token': grpc.unary_unary_rpc_method_handler(
                    servicer.Token,
                    request_deserializer=hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryTokenRequest.FromString,
                    response_serializer=hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryTokenResponse.SerializeToString,
            ),
            'BridgedSupply': grpc.unary_unary_rpc_method_handler(
                    servicer.BridgedSupply,
                    request_deserializer=hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryBridgedSupplyRequest.FromString,
                    response_serializer=hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryBridgedSupplyResponse.SerializeToString,
            ),
            'RemoteRouters': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoteRouters,
                    request_deserializer=hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryRemoteRoutersRequest.FromString,
                    response_serializer=hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryRemoteRoutersResponse.SerializeToString,
            ),
            'QuoteRemoteTransfer': grpc.unary_unary_rpc_method_handler(
                    servicer.QuoteRemoteTransfer,
                    request_deserializer=hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryQuoteRemoteTransferRequest.FromString,
                    response_serializer=hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryQuoteRemoteTransferResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'hyperlane.warp.v1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('hyperlane.warp.v1.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the module Query service.
    """

    @staticmethod
    def Tokens(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.warp.v1.Query/Tokens',
            hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryTokensRequest.SerializeToString,
            hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryTokensResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Token(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.warp.v1.Query/Token',
            hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryTokenRequest.SerializeToString,
            hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryTokenResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BridgedSupply(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.warp.v1.Query/BridgedSupply',
            hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryBridgedSupplyRequest.SerializeToString,
            hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryBridgedSupplyResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def RemoteRouters(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.warp.v1.Query/RemoteRouters',
            hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryRemoteRoutersRequest.SerializeToString,
            hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryRemoteRoutersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def QuoteRemoteTransfer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/hyperlane.warp.v1.Query/QuoteRemoteTransfer',
            hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryQuoteRemoteTransferRequest.SerializeToString,
            hyperlane_dot_warp_dot_v1_dot_query__pb2.QueryQuoteRemoteTransferResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/core/v1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dhyperlane/core/v1/types.proto\x12\x11hyperlane.core.v1\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x14gogoproto/gogo.proto\"\xb7\x04\n\x07Mailbox\x12S\n\x02id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x02id\x12.\n\x05owner\x18\x02 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\x05owner\x12!\n\x0cmessage_sent\x18\x03 \x01(\rR\x0bmessageSent\x12)\n\x10message_received\x18\x04 \x01(\rR\x0fmessageReceived\x12\x64\n\x0b\x64\x65\x66\x61ult_ism\x18\x05 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\ndefaultIsm\x12\x66\n\x0c\x64\x65\x66\x61ult_hook\x18\x06 \x01(\tBC\xc8\xde\x1f\x01\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x0b\x64\x65\x66\x61ultHook\x12h\n\rrequired_hook\x18\x07 \x01(\tBC\xc8\xde\x1f\x01\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x0crequiredHook\x12!\n\x0clocal_domain\x18\x08 \x01(\rR\x0blocalDomainB\xc3\x01\n\x15\x63om.hyperlane.core.v1B\nTypesProtoP\x01Z8github.com/bcp-innovations/hyperlane-cosmos/x/core/types\xa2\x02\x03HCX\xaa\x02\x11Hyperlane.Core.V1\xca\x02\x11Hyperlane\\Core\\V1\xe2\x02\x1dHyperlane\\Core\\V1\\GPBMetadata\xea\x02\x13Hyperlane::Core::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.core.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.hyperlane.core.v1B\nTypesProtoP\001Z8github.com/bcp-innovations/hyperlane-cosmos/x/core/types\242\002\003HCX\252\002\021Hyperlane.Core.V1\312\002\021Hyperlane\\Core\\V1\342\002\035Hyperlane\\Core\\V1\\GPBMetadata\352\002\023Hyperlane::Core::V1'
  _globals['_MAILBOX'].fields_by_name['id']._loaded_options = None
  _globals['_MAILBOX'].fields_by_name['id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MAILBOX'].fields_by_name['owner']._loaded_options = None
  _globals['_MAILBOX'].fields_by_name['owner']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MAILBOX'].fields_by_name['default_ism']._loaded_options = None
  _globals['_MAILBOX'].fields_by_name['default_ism']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MAILBOX'].fields_by_name['default_hook']._loaded_options = None
  _globals['_MAILBOX'].fields_by_name['default_hook']._serialized_options = b'\310\336\037\001\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MAILBOX'].fields_by_name['required_hook']._loaded_options = None
  _globals['_MAILBOX'].fields_by_name['required_hook']._serialized_options = b'\310\336\037\001\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_MAILBOX']._serialized_start=102
  _globals['_MAILBOX']._serialized_end=669
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/downtimedetector/v1beta1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from pyinjective.proto.injective.downtimedetector.v1beta1 import downtime_duration_pb2 as injective_dot_downtimedetector_dot_v1beta1_dot_downtime__duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0injective/downtimedetector/v1beta1/genesis.proto\x12\"injective.downtimedetector.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x19google/protobuf/any.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a:injective/downtimedetector/v1beta1/downtime_duration.proto\"\xd8\x01\n\x14GenesisDowntimeEntry\x12]\n\x08\x64uration\x18\x01 \x01(\x0e\x32,.injective.downtimedetector.v1beta1.DowntimeB\x13\xf2\xde\x1f\x0fyaml:\"duration\"R\x08\x64uration\x12\x61\n\rlast_downtime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB \xc8\xde\x1f\x00\xf2\xde\x1f\x14yaml:\"last_downtime\"\x90\xdf\x1f\x01R\x0clastDowntime\"\xd4\x01\n\x0cGenesisState\x12\\\n\tdowntimes\x18\x01 \x03(\x0b\x32\x38.injective.downtimedetector.v1beta1.GenesisDowntimeEntryB\x04\xc8\xde\x1f\x00R\tdowntimes\x12\x66\n\x0flast_block_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\"\xc8\xde\x1f\x00\xf2\xde\x1f\x16yaml:\"last_block_time\"\x90\xdf\x1f\x01R\rlastBlockTimeB\xb9\x02\n&com.injective.downtimedetector.v1beta1B\x0cGenesisProtoP\x01ZWgithub.com/InjectiveLabs/injective-core/injective-chain/modules/downtime-detector/types\xa2\x02\x03IDX\xaa\x02\"Injective.Downtimedetector.V1beta1\xca\x02\"Injective\\Downtimedetector\\V1beta1\xe2\x02.Injective\\Downtimedetector\\V1beta1\\GPBMetadata\xea\x02$Injective::Downtimedetector::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.downtimedetector.v1beta1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&com.injective.downtimedetector.v1beta1B\014GenesisProtoP\001ZWgithub.com/InjectiveLabs/injective-core/injective-chain/modules/downtime-detector/types\242\002\003IDX\252\002\"Injective.Downtimedetector.V1beta1\312\002\"Injective\\Downtimedetector\\V1beta1\342\002.Injective\\Downtimedetector\\V1beta1\\GPBMetadata\352\002$Injective::Downtimedetector::V1beta1'
  _globals['_GENESISDOWNTIMEENTRY'].fields_by_name['duration']._loaded_options = None
  _globals['_GENESISDOWNTIMEENTRY'].fields_by_name['duration']._serialized_options = b'\362\336\037\017yaml:\"duration\"'
  _globals['_GENESISDOWNTIMEENTRY'].fields_by_name['last_downtime']._loaded_options = None
  _globals['_GENESISDOWNTIMEENTRY'].fields_by_name['last_downtime']._serialized_options = b'\310\336\037\000\362\336\037\024yaml:\"last_downtime\"\220\337\037\001'
  _globals['_GENESISSTATE'].fields_by_name['downtimes']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['downtimes']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['last_block_time']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['last_block_time']._serialized_options = b'\310\336\037\000\362\336\037\026yaml:\"last_block_time\"\220\337\037\001'
  _globals['_GENESISDOWNTIMEENTRY']._serialized_start=290
  _globals['_GENESISDOWNTIMEENTRY']._serialized_end=506
  _globals['_GENESISSTATE']._serialized_start=509
  _globals['_GENESISSTATE']._serialized_end=721
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hyperlane/warp/v1/events.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ehyperlane/warp/v1/events.proto\x12\x11hyperlane.warp.v1\x1a\x14gogoproto/gogo.proto\"\xa0\x02\n\x19\x45ventCreateSyntheticToken\x12^\n\x08token_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x07tokenId\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12j\n\x0eorigin_mailbox\x18\x03 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\roriginMailbox\x12!\n\x0corigin_denom\x18\x04 \x01(\tR\x0boriginDenom\"\xa1\x02\n\x1a\x45ventCreateCollateralToken\x12^\n\x08token_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x07tokenId\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12j\n\x0eorigin_mailbox\x18\x03 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\roriginMailbox\x12!\n\x0corigin_denom\x18\x04 \x01(\tR\x0boriginDenom\"\xe8\x01\n\rEventSetToken\x12\x19\n\x08token_id\x18\x01 \x01(\tR\x07tokenId\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12Z\n\x06ism_id\x18\x03 \x01(\tBC\xc8\xde\x1f\x01\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x05ismId\x12\x1b\n\tnew_owner\x18\x04 \x01(\tR\x08newOwner\x12-\n\x12renounce_ownership\x18\x05 \x01(\x08R\x11renounceOwnership\"\xd1\x01\n\x17\x45ventEnrollRemoteRouter\x12\x19\n\x08token_id\x18\x01 \x01(\tR\x07tokenId\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12\'\n\x0freceiver_domain\x18\x03 \x01(\rR\x0ereceiverDomain\x12+\n\x11receiver_contract\x18\x04 \x01(\tR\x10receiverContract\x12/\n\x03gas\x18\x05 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x03gas\"s\n\x17\x45ventUnrollRemoteRouter\x12\x19\n\x08token_id\x18\x01 \x01(\tR\x07tokenId\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12\'\n\x0freceiver_domain\x18\x03 \x01(\rR\x0ereceiverDomain\"\xbb\x02\n\x17\x45ventSendRemoteTransfer\x12^\n\x08token_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x07tokenId\x12\x16\n\x06sender\x18\x02 \x01(\tR\x06sender\x12-\n\x12\x64\x65stination_domain\x18\x03 \x01(\rR\x11\x64\x65stinationDomain\x12\x61\n\trecipient\x18\x04 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\trecipient\x12\x16\n\x06\x61mount\x18\x05 \x01(\tR\x06\x61mount\"\xb4\x02\n\x1a\x45ventReceiveRemoteTransfer\x12^\n\x08token_id\x18\x01 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x07tokenId\x12[\n\x06sender\x18\x02 \x01(\tBC\xc8\xde\x1f\x00\xda\xde\x1f;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddressR\x06sender\x12#\n\rorigin_domain\x18\x03 \x01(\rR\x0coriginDomain\x12\x1c\n\trecipient\x18\x04 \x01(\tR\trecipient\x12\x16\n\x06\x61mount\x18\x05 \x01(\tR\x06\x61mountB\xc4\x01\n\x15\x63om.hyperlane.warp.v1B\x0b\x45ventsProtoP\x01Z8github.com/bcp-innovations/hyperlane-cosmos/x/warp/types\xa2\x02\x03HWX\xaa\x02\x11Hyperlane.Warp.V1\xca\x02\x11Hyperlane\\Warp\\V1\xe2\x02\x1dHyperlane\\Warp\\V1\\GPBMetadata\xea\x02\x13Hyperlane::Warp::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'hyperlane.warp.v1.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.hyperlane.warp.v1B\013EventsProtoP\001Z8github.com/bcp-innovations/hyperlane-cosmos/x/warp/types\242\002\003HWX\252\002\021Hyperlane.Warp.V1\312\002\021Hyperlane\\Warp\\V1\342\002\035Hyperlane\\Warp\\V1\\GPBMetadata\352\002\023Hyperlane::Warp::V1'
  _globals['_EVENTCREATESYNTHETICTOKEN'].fields_by_name['token_id']._loaded_options = None
  _globals['_EVENTCREATESYNTHETICTOKEN'].fields_by_name['token_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTCREATESYNTHETICTOKEN'].fields_by_name['origin_mailbox']._loaded_options = None
  _globals['_EVENTCREATESYNTHETICTOKEN'].fields_by_name['origin_mailbox']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTCREATECOLLATERALTOKEN'].fields_by_name['token_id']._loaded_options = None
  _globals['_EVENTCREATECOLLATERALTOKEN'].fields_by_name['token_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTCREATECOLLATERALTOKEN'].fields_by_name['origin_mailbox']._loaded_options = None
  _globals['_EVENTCREATECOLLATERALTOKEN'].fields_by_name['origin_mailbox']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTSETTOKEN'].fields_by_name['ism_id']._loaded_options = None
  _globals['_EVENTSETTOKEN'].fields_by_name['ism_id']._serialized_options = b'\310\336\037\001\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTENROLLREMOTEROUTER'].fields_by_name['gas']._loaded_options = None
  _globals['_EVENTENROLLREMOTEROUTER'].fields_by_name['gas']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_EVENTSENDREMOTETRANSFER'].fields_by_name['token_id']._loaded_options = None
  _globals['_EVENTSENDREMOTETRANSFER'].fields_by_name['token_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTSENDREMOTETRANSFER'].fields_by_name['recipient']._loaded_options = None
  _globals['_EVENTSENDREMOTETRANSFER'].fields_by_name['recipient']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTRECEIVEREMOTETRANSFER'].fields_by_name['token_id']._loaded_options = None
  _globals['_EVENTRECEIVEREMOTETRANSFER'].fields_by_name['token_id']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTRECEIVEREMOTETRANSFER'].fields_by_name['sender']._loaded_options = None
  _globals['_EVENTRECEIVEREMOTETRANSFER'].fields_by_name['sender']._serialized_options = b'\310\336\037\000\332\336\037;github.com/bcp-innovations/hyperlane-cosmos/util.HexAddress'
  _globals['_EVENTCREATESYNTHETICTOKEN']._serialized_start=76
  _globals['_EVENTCREATESYNTHETICTOKEN']._serialized_end=364
  _globals['_EVENTCREATECOLLATERALTOKEN']._serialized_start=367
  _globals['_EVENTCREATECOLLATERALTOKEN']._serialized_end=656
  _globals['_EVENTSETTOKEN']._serialized_start=659
  _globals['_EVENTSETTOKEN']._serialized_end=891
  _globals['_EVENTENROLLREMOTEROUTER']._serialized_start=894
  _globals['_EVENTENROLLREMOTEROUTER']._serialized_end=1103
  _globals['_EVENTUNROLLREMOTEROUTER']._serialized_start=1105
  _globals['_EVENTUNROLLREMOTEROUTER']._serialized_end=1220
  _globals['_EVENTSENDREMOTETRANSFER']._serialized_start=1223
  _globals['_EVENTSENDREMOTETRANSFER']._serialized_end=1538
  _globals['_EVENTRECEIVEREMOTETRANSFER']._serialized_start=1541
  _globals['_EVENTRECEIVEREMOTETRANSFER']._serialized_end=1849
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_auction_rpc.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$exchange/injective_auction_rpc.proto\x12\x15injective_auction_rpc\".\n\x16\x41uctionEndpointRequest\x12\x14\n\x05round\x18\x01 \x01(\x12R\x05round\"\x83\x01\n\x17\x41uctionEndpointResponse\x12\x38\n\x07\x61uction\x18\x01 \x01(\x0b\x32\x1e.injective_auction_rpc.AuctionR\x07\x61uction\x12.\n\x04\x62ids\x18\x02 \x03(\x0b\x32\x1a.injective_auction_rpc.BidR\x04\x62ids\"\xa2\x02\n\x07\x41uction\x12\x16\n\x06winner\x18\x01 \x01(\tR\x06winner\x12\x33\n\x06\x62\x61sket\x18\x02 \x03(\x0b\x32\x1b.injective_auction_rpc.CoinR\x06\x62\x61sket\x12,\n\x12winning_bid_amount\x18\x03 \x01(\tR\x10winningBidAmount\x12\x14\n\x05round\x18\x04 \x01(\x04R\x05round\x12#\n\rend_timestamp\x18\x05 \x01(\x12R\x0c\x65ndTimestamp\x12\x1d\n\nupdated_at\x18\x06 \x01(\x12R\tupdatedAt\x12\x42\n\x08\x63ontract\x18\x07 \x01(\x0b\x32&.injective_auction_rpc.AuctionContractR\x08\x63ontract\"Q\n\x04\x43oin\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x16\n\x06\x61mount\x18\x02 \x01(\tR\x06\x61mount\x12\x1b\n\tusd_value\x18\x03 \x01(\tR\x08usdValue\"\xb4\x03\n\x0f\x41uctionContract\x12\x0e\n\x02id\x18\x01 \x01(\x04R\x02id\x12\x1d\n\nbid_target\x18\x02 \x01(\tR\tbidTarget\x12#\n\rcurrent_slots\x18\x03 \x01(\x04R\x0c\x63urrentSlots\x12\x1f\n\x0btotal_slots\x18\x04 \x01(\x04R\ntotalSlots\x12.\n\x13max_user_allocation\x18\x05 \x01(\tR\x11maxUserAllocation\x12\'\n\x0ftotal_committed\x18\x06 \x01(\tR\x0etotalCommitted\x12/\n\x13whitelist_addresses\x18\x07 \x03(\tR\x12whitelistAddresses\x12\'\n\x0fstart_timestamp\x18\x08 \x01(\x04R\x0estartTimestamp\x12#\n\rend_timestamp\x18\t \x01(\x04R\x0c\x65ndTimestamp\x12\x30\n\x14max_round_allocation\x18\n \x01(\tR\x12maxRoundAllocation\x12\"\n\ris_bid_placed\x18\x0b \x01(\x08R\x0bisBidPlaced\"S\n\x03\x42id\x12\x16\n\x06\x62idder\x18\x01 \x01(\tR\x06\x62idder\x12\x16\n\x06\x61mount\x18\x02 \x01(\tR\x06\x61mount\x12\x1c\n\ttimestamp\x18\x03 \x01(\x12R\ttimestamp\"\x11\n\x0f\x41uctionsRequest\"N\n\x10\x41uctionsResponse\x12:\n\x08\x61uctions\x18\x01 \x03(\x0b\x32\x1e.injective_auction_rpc.AuctionR\x08\x61uctions\"f\n\x18\x41uctionsHistoryV2Request\x12\x19\n\x08per_page\x18\x01 \x01(\x11R\x07perPage\x12\x14\n\x05token\x18\x02 \x01(\tR\x05token\x12\x19\n\x08\x65nd_time\x18\x03 \x01(\x12R\x07\x65ndTime\"s\n\x19\x41uctionsHistoryV2Response\x12\x42\n\x08\x61uctions\x18\x01 \x03(\x0b\x32&.injective_auction_rpc.AuctionV2ResultR\x08\x61uctions\x12\x12\n\x04next\x18\x02 \x03(\tR\x04next\"\xe5\x02\n\x0f\x41uctionV2Result\x12\x16\n\x06winner\x18\x01 \x01(\tR\x06winner\x12\x39\n\x06\x62\x61sket\x18\x02 \x03(\x0b\x32!.injective_auction_rpc.CoinPricesR\x06\x62\x61sket\x12,\n\x12winning_bid_amount\x18\x03 \x01(\tR\x10winningBidAmount\x12\x14\n\x05round\x18\x04 \x01(\x04R\x05round\x12#\n\rend_timestamp\x18\x05 \x01(\x12R\x0c\x65ndTimestamp\x12\x1d\n\nupdated_at\x18\x06 \x01(\x12R\tupdatedAt\x12\x42\n\x08\x63ontract\x18\x07 \x01(\x0b\x32&.injective_auction_rpc.AuctionContractR\x08\x63ontract\x12\x33\n\x16winning_bid_amount_usd\x18\x08 \x01(\tR\x13winningBidAmountUsd\"\xbc\x01\n\nCoinPrices\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x16\n\x06\x61mount\x18\x02 \x01(\tR\x06\x61mount\x12\x45\n\x06prices\x18\x03 \x03(\x0b\x32-.injective_auction_rpc.CoinPrices.PricesEntryR\x06prices\x1a\x39\n\x0bPricesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"(\n\x10\x41uctionV2Request\x12\x14\n\x05round\x18\x01 \x01(\x12R\x05round\"\xe7\x02\n\x11\x41uctionV2Response\x12\x16\n\x06winner\x18\x01 \x01(\tR\x06winner\x12\x39\n\x06\x62\x61sket\x18\x02 \x03(\x0b\x32!.injective_auction_rpc.CoinPricesR\x06\x62\x61sket\x12,\n\x12winning_bid_amount\x18\x03 \x01(\tR\x10winningBidAmount\x12\x14\n\x05round\x18\x04 \x01(\x04R\x05round\x12#\n\rend_timestamp\x18\x05 \x01(\x12R\x0c\x65ndTimestamp\x12\x1d\n\nupdated_at\x18\x06 \x01(\x12R\tupdatedAt\x12\x42\n\x08\x63ontract\x18\x07 \x01(\x0b\x32&.injective_auction_rpc.AuctionContractR\x08\x63ontract\x12\x33\n\x16winning_bid_amount_usd\x18\x08 \x01(\tR\x13winningBidAmountUsd\"e\n\x18\x41\x63\x63ountAuctionsV2Request\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x19\n\x08per_page\x18\x02 \x01(\x11R\x07perPage\x12\x14\n\x05token\x18\x03 \x01(\tR\x05token\"\x8a\x01\n\x19\x41\x63\x63ountAuctionsV2Response\x12\x43\n\x08\x61uctions\x18\x01 \x03(\x0b\x32\'.injective_auction_rpc.AccountAuctionV2R\x08\x61uctions\x12\x12\n\x04next\x18\x02 \x03(\tR\x04next\x12\x14\n\x05total\x18\x03 \x01(\x12R\x05total\"\xd0\x01\n\x10\x41\x63\x63ountAuctionV2\x12\x0e\n\x02id\x18\x01 \x01(\x04R\x02id\x12\x14\n\x05round\x18\x02 \x01(\x04R\x05round\x12)\n\x10\x61mount_deposited\x18\x03 \x01(\tR\x0f\x61mountDeposited\x12!\n\x0cis_claimable\x18\x04 \x01(\x08R\x0bisClaimable\x12H\n\x0e\x63laimed_assets\x18\x05 \x03(\x0b\x32!.injective_auction_rpc.CoinPricesR\rclaimedAssets\"M\n\x1b\x41uctionAccountStatusRequest\x12\x14\n\x05round\x18\x01 \x01(\x12R\x05round\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\"6\n\x1c\x41uctionAccountStatusResponse\x12\x16\n\x06status\x18\x01 \x01(\tR\x06status\"\x13\n\x11StreamBidsRequest\"\x7f\n\x12StreamBidsResponse\x12\x16\n\x06\x62idder\x18\x01 \x01(\tR\x06\x62idder\x12\x1d\n\nbid_amount\x18\x02 \x01(\tR\tbidAmount\x12\x14\n\x05round\x18\x03 \x01(\x04R\x05round\x12\x1c\n\ttimestamp\x18\x04 \x01(\x12R\ttimestamp\"\x19\n\x17InjBurntEndpointRequest\"B\n\x18InjBurntEndpointResponse\x12&\n\x0ftotal_inj_burnt\x18\x01 \x01(\tR\rtotalInjBurnt\"\x16\n\x14\x41uctionsStatsRequest\"`\n\x15\x41uctionsStatsResponse\x12\x1f\n\x0btotal_burnt\x18\x01 \x01(\tR\ntotalBurnt\x12&\n\x0ftotal_usd_value\x18\x02 \x01(\tR\rtotalUsdValue2\xfb\x07\n\x13InjectiveAuctionRPC\x12p\n\x0f\x41uctionEndpoint\x12-.injective_auction_rpc.AuctionEndpointRequest\x1a..injective_auction_rpc.AuctionEndpointResponse\x12[\n\x08\x41uctions\x12&.injective_auction_rpc.AuctionsRequest\x1a\'.injective_auction_rpc.AuctionsResponse\x12v\n\x11\x41uctionsHistoryV2\x12/.injective_auction_rpc.AuctionsHistoryV2Request\x1a\x30.injective_auction_rpc.AuctionsHistoryV2Response\x12^\n\tAuctionV2\x12\'.injective_auction_rpc.AuctionV2Request\x1a(.injective_auction_rpc.AuctionV2Response\x12v\n\x11\x41\x63\x63ountAuctionsV2\x12/.injective_auction_rpc.AccountAuctionsV2Request\x1a\x30.injective_auction_rpc.AccountAuctionsV2Response\x12\x7f\n\x14\x41uctionAccountStatus\x12\x32.injective_auction_rpc.AuctionAccountStatusRequest\x1a\x33.injective_auction_rpc.AuctionAccountStatusResponse\x12\x63\n\nStreamBids\x12(.injective_auction_rpc.StreamBidsRequest\x1a).injective_auction_rpc.StreamBidsResponse0\x01\x12s\n\x10InjBurntEndpoint\x12..injective_auction_rpc.InjBurntEndpointRequest\x1a/.injective_auction_rpc.InjBurntEndpointResponse\x12j\n\rAuctionsStats\x12+.injective_auction_rpc.AuctionsStatsRequest\x1a,.injective_auction_rpc.AuctionsStatsResponseB\xbb\x01\n\x19\x63om.injective_auction_rpcB\x18InjectiveAuctionRpcProtoP\x01Z\x18/injective_auction_rpcpb\xa2\x02\x03IXX\xaa\x02\x13InjectiveAuctionRpc\xca\x02\x13InjectiveAuctionRpc\xe2\x02\x1fInjectiveAuctionRpc\\GPBMetadata\xea\x02\x13InjectiveAuctionRpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_auction_rpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.injective_auction_rpcB\030InjectiveAuctionRpcProtoP\001Z\030/injective_auction_rpcpb\242\002\003IXX\252\002\023InjectiveAuctionRpc\312\002\023InjectiveAuctionRpc\342\002\037InjectiveAuctionRpc\\GPBMetadata\352\002\023InjectiveAuctionRpc'
  _globals['_COINPRICES_PRICESENTRY']._loaded_options = None
  _globals['_COINPRICES_PRICESENTRY']._serialized_options = b'8\001'
  _globals['_AUCTIONENDPOINTREQUEST']._serialized_start=63
  _globals['_AUCTIONENDPOINTREQUEST']._serialized_end=109
  _globals['_AUCTIONENDPOINTRESPONSE']._serialized_start=112
  _globals['_AUCTIONENDPOINTRESPONSE']._serialized_end=243
  _globals['_AUCTION']._serialized_start=246
  _globals['_AUCTION']._serialized_end=536
  _globals['_COIN']._serialized_start=538
  _globals['_COIN']._serialized_end=619
  _globals['_AUCTIONCONTRACT']._serialized_start=622
  _globals['_AUCTIONCONTRACT']._serialized_end=1058
  _globals['_BID']._serialized_start=1060
  _globals['_BID']._serialized_end=1143
  _globals['_AUCTIONSREQUEST']._serialized_start=1145
  _globals['_AUCTIONSREQUEST']._serialized_end=1162
  _globals['_AUCTIONSRESPONSE']._serialized_start=1164
  _globals['_AUCTIONSRESPONSE']._serialized_end=1242
  _globals['_AUCTIONSHISTORYV2REQUEST']._serialized_start=1244
  _globals['_AUCTIONSHISTORYV2REQUEST']._serialized_end=1346
  _globals['_AUCTIONSHISTORYV2RESPONSE']._serialized_start=1348
  _globals['_AUCTIONSHISTORYV2RESPONSE']._serialized_end=1463
  _globals['_AUCTIONV2RESULT']._serialized_start=1466
  _globals['_AUCTIONV2RESULT']._serialized_end=1823
  _globals['_COINPRICES']._serialized_start=1826
  _globals['_COINPRICES']._serialized_end=2014
  _globals['_COINPRICES_PRICESENTRY']._serialized_start=1957
  _globals['_COINPRICES_PRICESENTRY']._serialized_end=2014
  _globals['_AUCTIONV2REQUEST']._serialized_start=2016
  _globals['_AUCTIONV2REQUEST']._serialized_end=2056
  _globals['_AUCTIONV2RESPONSE']._serialized_start=2059
  _globals['_AUCTIONV2RESPONSE']._serialized_end=2418
  _globals['_ACCOUNTAUCTIONSV2REQUEST']._serialized_start=2420
  _globals['_ACCOUNTAUCTIONSV2REQUEST']._serialized_end=2521
  _globals['_ACCOUNTAUCTIONSV2RESPONSE']._serialized_start=2524
  _globals['_ACCOUNTAUCTIONSV2RESPONSE']._serialized_end=2662
  _globals['_ACCOUNTAUCTIONV2']._serialized_start=2665
  _globals['_ACCOUNTAUCTIONV2']._serialized_end=2873
  _globals['_AUCTIONACCOUNTSTATUSREQUEST']._serialized_start=2875
  _globals['_AUCTIONACCOUNTSTATUSREQUEST']._serialized_end=2952
  _globals['_AUCTIONACCOUNTSTATUSRESPONSE']._serialized_start=2954
  _globals['_AUCTIONACCOUNTSTATUSRESPONSE']._serialized_end=3008
  _globals['_STREAMBIDSREQUEST']._serialized_start=3010
  _globals['_STREAMBIDSREQUEST']._serialized_end=3029
  _globals['_STREAMBIDSRESPONSE']._serialized_start=3031
  _globals['_STREAMBIDSRESPONSE']._serialized_end=3158
  _globals['_INJBURNTENDPOINTREQUEST']._serialized_start=3160
  _globals['_INJBURNTENDPOINTREQUEST']._serialized_end=3185
  _globals['_INJBURNTENDPOINTRESPONSE']._serialized_start=3187
  _globals['_INJBURNTENDPOINTRESPONSE']._serialized_end=3253
  _globals['_AUCTIONSSTATSREQUEST']._serialized_start=3255
  _globals['_AUCTIONSSTATSREQUEST']._serialized_end=3277
  _globals['_AUCTIONSSTATSRESPONSE']._serialized_start=3279
  _globals['_AUCTIONSSTATSRESPONSE']._serialized_end=3375
  _globals['_INJECTIVEAUCTIONRPC']._serialized_start=3378
  _globals['_INJECTIVEAUCTIONRPC']._serialized_end=4397
# @@protoc_insertion_point(module_scope)
